@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-from AccessControl.unauthorized import Unauthorized
 from copy import deepcopy
 from plone import api
-from plone.indexer.interfaces import IIndexableObject
 from plone.restapi.behaviors import IBlocks
 from plone.restapi.interfaces import IBlockFieldSerializationTransformer
 from plone.restapi.interfaces import ISerializeToJsonSummary
@@ -11,7 +9,6 @@ from Products.CMFPlone.interfaces import IPloneSiteRoot
 from redturtle.volto.interfaces import IRedturtleVoltoLayer
 from zope.component import adapter
 from zope.component import getMultiAdapter
-from zope.component import queryMultiAdapter
 from zope.globalrequest import getRequest
 from zope.interface import implementer
 
@@ -78,22 +75,33 @@ class GenericResolveUIDSerializer(object):
         This could lead to a huge amount of data returned.
         We need to wrap the item with IIndexableObject to be able to get all metadata like it was a brain.
         """
-        try:
-            item = api.content.get(UID=block["UID"])
-        except Unauthorized:
-            return {}
-        if item:
-            wrapper = queryMultiAdapter(
-                (
-                    item,
-                    self.context.portal_catalog,
-                ),
-                IIndexableObject,
-            )
-            adapter = getMultiAdapter((wrapper, getRequest()), ISerializeToJsonSummary)
-            return adapter(force_all_metadata=True)
-        else:
+        items = api.content.find(UID=block["UID"], show_inactive=False)
+        if len(items) == 0:
             return {}
+        item = items[0]
+
+        adapter = getMultiAdapter((item, getRequest()), ISerializeToJsonSummary)
+        return adapter(force_all_metadata=True)
+
+
+class TableResolveUIDSerializer(object):
+    """ """
+
+    order = 210  # after standard ones
+    block_type = "table"
+
+    def __init__(self, context, request):
+        self.context = context
+        self.request = request
+
+    def __call__(self, value):
+        for row in value.get("table", {}).get("rows", []):
+            for cell in row.get("cells", []):
+                for entity in cell.get("value", {}).get("entityMap", {}).values():
+                    if entity.get("type") == "LINK":
+                        url = entity.get("data", {}).get("url", "")
+                        entity["data"]["url"] = uid_to_url(url)
+        return value
 
 
 @implementer(IBlockFieldSerializationTransformer)
@@ -106,3 +114,15 @@ class GenericResolveUIDSerializerContents(GenericResolveUIDSerializer):
 @adapter(IPloneSiteRoot, IRedturtleVoltoLayer)
 class GenericResolveUIDSerializerRoot(GenericResolveUIDSerializer):
     """Deserializer for site-root"""
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IBlocks, IRedturtleVoltoLayer)
+class TableResolveUIDSerializerContents(TableResolveUIDSerializer):
+    """Deserializer for content-types that implements IBlocks behavior"""
+
+
+@implementer(IBlockFieldSerializationTransformer)
+@adapter(IPloneSiteRoot, IRedturtleVoltoLayer)
+class TableResolveUIDSerializerRoot(TableResolveUIDSerializer):
+    """Deserializer for site-root"""
